@@ -1,11 +1,17 @@
 import asyncio
 from typing import Any
 from typing import Dict
+from typing import List
 
 import dict_tools.update
 
 
-async def unlock(hub, profiles: Dict[str, Dict[str, Any]], backend_key: str = None):
+async def unlock(
+    hub,
+    profiles: Dict[str, Dict[str, Any]],
+    backend_key: str = None,
+    allowed_backend_profiles: List[str] = None,
+):
     """
     Read the raw profiles and search for externally defined profiles.
     """
@@ -21,6 +27,14 @@ async def unlock(hub, profiles: Dict[str, Dict[str, Any]], backend_key: str = No
             continue
         # The keys are irrelevant for backend profiles
         for backend_profile_name, ctx in backend_profile_data.items():
+            if (
+                allowed_backend_profiles
+                and backend_profile_name not in allowed_backend_profiles
+            ):
+                hub.log.info(
+                    f"acct backend profile not on allow-list from {'backend'}: {backend_profile_name}"
+                )
+                continue
             try:
                 hub.log.info(
                     f"Reading acct backend profiles from '{backend}': {backend_profile_name}"
